Release notes
=============

This project uses `semantic versioning <http://semver.org/>`_.

2.0.0 (2017-08-09)
------------------

Added
^^^^^

- `ccr` command

Changed
^^^^^^^

- Moved to Python 3.6
- Removed entry point

1.1.0 (2016-11-25)
------------------

Changed
^^^^^^^

- Aligned output of decimal, octal, and hexadecimal representations.
- Added more information to control character formatting.

1.0.0 (2016-11-20)
------------------

Initial release.
